@@ -13,11 +13,18 @@ type PodSpec struct {
 	v1.PodSpec
 }
 
-// AllContainers returns a list of all containers in the Pod, both Init and Regular
+// AllContainers returns a list of all containers in the Pod, including Init, Regular, and Ephemeral
 func (p *PodSpec) AllContainers() []v1.Container {
 	allContainers := make([]v1.Container, 0, len(p.PodSpec.InitContainers)+len(p.PodSpec.Containers))
 	allContainers = append(allContainers, p.PodSpec.InitContainers...)
 	allContainers = append(allContainers, p.PodSpec.Containers...)
+
+	// Per KEP277, EphemeralContainerCommon is required by the compiler to be field-for-field matching with v1.Container
+	// https://github.com/kubernetes/enhancements/blob/master/keps/sig-node/277-ephemeral-containers/README.md
+	for _, e := range p.PodSpec.EphemeralContainers {
+		allContainers = append(allContainers, v1.Container(e.EphemeralContainerCommon))
+	}
+
 	return allContainers
 }
 
@@ -30,3 +37,8 @@ func (p *PodSpec) NonInitContainers() []v1.Container {
 func (p *PodSpec) InitContainers() []v1.Container {
 	return p.PodSpec.InitContainers
 }
+
+// EphemeralContainers returns a list of all ephemeral containers in the Pod
+func (p *PodSpec) EphemeralContainers() []v1.EphemeralContainer {
+	return p.PodSpec.EphemeralContainers
+}
