@@ -7,6 +7,8 @@ import (
 	"path/filepath"
 	"testing"
 
+	"golang.stackrox.io/kube-linter/pkg/pathutil"
+
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -16,11 +18,63 @@ const (
 	chartDirectory     = "../../tests/testdata/mychart"
 	renamedTarball     = "../../tests/testdata/my-renamed-chart-0.1.0.tgz"
 	renamedChartDir    = "../../tests/testdata/my-renamed-chart"
-	mockIgnorePath     = "../../tests/testdata/"
+	mockIgnorePath     = "../../tests/testdata/**"
 	mockGlobIgnorePath = "../../tests/**"
 	mockPath           = "mock path"
 )
 
+func TestCreateContextsWithIgnorePaths(t *testing.T) {
+	ignoredPaths := []string{
+		"../../.github/**",
+		"../../.golangci?yml",
+		"../../.goreleaser.yaml",
+		"../../.pre-commit-hooks*",
+		"../../dist/**/*",
+		"../../pkg/**/*",
+		"/**/*/checks/**/*",
+		"/**/*/test_helper/**/*",
+		"/**/*/testdata/**/*",
+	}
+	ignoredAbsPaths := make([]string, 0, len(ignoredPaths))
+	for _, p := range ignoredPaths {
+		abs, err := pathutil.GetAbsolutPath(p)
+		assert.NoError(t, err)
+		ignoredAbsPaths = append(ignoredAbsPaths, abs)
+	}
+
+	testPath := "../../"
+	contexts, err := CreateContexts(ignoredAbsPaths, testPath)
+	assert.NoError(t, err)
+	checkEmptyLintContext(t, contexts)
+}
+
+func TestIgnoreSubchartManifests(t *testing.T) {
+	ignorePaths := []string{
+		"../../tests/testdata/mychart/charts/**",
+	}
+	dir := "../../tests/testdata/mychart"
+
+	lintCtxs, err := CreateContexts(ignorePaths, dir)
+	require.NoError(t, err)
+	lintCtx := lintCtxs[0]
+	objects := lintCtx.Objects()
+
+	actualPaths := make([]string, 0, len(objects))
+	for _, obj := range objects {
+		actualPaths = append(actualPaths, obj.Metadata.FilePath)
+	}
+
+	expectedPaths := []string{
+		"../../tests/testdata/mychart/templates/serviceaccount.yaml",
+		"../../tests/testdata/mychart/templates/service.yaml",
+		"../../tests/testdata/mychart/templates/hpa.yaml",
+		"../../tests/testdata/mychart/templates/deployment.yaml",
+		"../../tests/testdata/mychart/templates/tests/test-connection.yaml",
+	}
+
+	assert.ElementsMatch(t, expectedPaths, actualPaths)
+}
+
 func TestCreateContextsObjectPaths(t *testing.T) {
 	bools := []bool{false, true}
 
@@ -92,7 +146,7 @@ func createContextsAndVerifyPaths(t *testing.T, useTarball, useAbsolutePath, ren
 			require.NoError(t, file.Close())
 		}()
 
-		lintCtxs, err = CreateContextsFromHelmArchive(mockPath, file)
+		lintCtxs, err = CreateContextsFromHelmArchive(testIgnorePaths, mockPath, file)
 	} else {
 		lintCtxs, err = CreateContexts(testIgnorePaths, testPath)
 	}
@@ -116,7 +170,7 @@ func createContextsAndVerifyPaths(t *testing.T, useTarball, useAbsolutePath, ren
 }
 
 func checkEmptyLintContext(t *testing.T, lintCtxs []LintContext) {
-	assert.Len(t, lintCtxs, 0, "expecting no lint context")
+	assert.Empty(t, lintCtxs, "expecting no lint context")
 }
 
 func verifyAndGetContext(t *testing.T, lintCtxs []LintContext) LintContext {
@@ -140,6 +194,7 @@ func checkObjectPaths(t *testing.T, objects []Object, expectedPrefix string) {
 		path.Join(expectedPrefix, "templates/service.yaml"),
 		path.Join(expectedPrefix, "templates/serviceaccount.yaml"),
 		path.Join(expectedPrefix, "templates/tests/test-connection.yaml"),
+		path.Join(expectedPrefix, "charts/subchart/templates/deployment.yaml"),
 	}
 	assert.ElementsMatchf(t, expectedPaths, actualPaths, "expected and actual template paths don't match")
 }
