@@ -3,6 +3,7 @@ package lintcontext
 import (
 	"bufio"
 	"bytes"
+	"errors"
 	"fmt"
 	"io"
 	"log"
@@ -10,9 +11,11 @@ import (
 	"path/filepath"
 	"strings"
 
-	y "github.com/ghodss/yaml"
+	"github.com/bmatcuk/doublestar/v4"
+	kedaV1Alpha1 "github.com/kedacore/keda/v2/apis/keda/v1alpha1"
 	ocsAppsV1 "github.com/openshift/api/apps/v1"
-	"github.com/pkg/errors"
+	ocpSecV1 "github.com/openshift/api/security/v1"
+	k8sMonitoring "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
 	"golang.stackrox.io/kube-linter/pkg/k8sutil"
 	"helm.sh/helm/v3/pkg/chart"
 	"helm.sh/helm/v3/pkg/chart/loader"
@@ -25,6 +28,7 @@ import (
 	"k8s.io/apimachinery/pkg/runtime/serializer"
 	"k8s.io/apimachinery/pkg/util/yaml"
 	"k8s.io/client-go/kubernetes/scheme"
+	y "sigs.k8s.io/yaml"
 )
 
 const (
@@ -41,7 +45,7 @@ func init() {
 	clientScheme := scheme.Scheme
 
 	// Add OpenShift and Autoscaling schema
-	schemeBuilder := runtime.NewSchemeBuilder(ocsAppsV1.AddToScheme, autoscalingV2Beta1.AddToScheme)
+	schemeBuilder := runtime.NewSchemeBuilder(ocsAppsV1.AddToScheme, autoscalingV2Beta1.AddToScheme, k8sMonitoring.AddToScheme, ocpSecV1.AddToScheme, kedaV1Alpha1.AddToScheme)
 	if err := schemeBuilder.AddToScheme(clientScheme); err != nil {
 		panic(fmt.Sprintf("Can not add OpenShift schema %v", err))
 	}
@@ -54,18 +58,18 @@ func parseObjects(data []byte, d runtime.Decoder) ([]k8sutil.Object, error) {
 	}
 	obj, _, err := d.Decode(data, nil, nil)
 	if err != nil {
-		return nil, errors.Wrap(err, "failed to decode")
+		return nil, fmt.Errorf("failed to decode: %w", err)
 	}
 	if list, ok := obj.(*v1.List); ok {
 		objs := make([]k8sutil.Object, 0, len(list.Items))
 		for i, item := range list.Items {
 			obj, _, err := d.Decode(item.Raw, nil, nil)
 			if err != nil {
-				return nil, errors.Wrapf(err, "decoding item %d in the list", i)
+				return nil, fmt.Errorf("decoding item %d in the list: %w", i, err)
 			}
 			asK8sObj, _ := obj.(k8sutil.Object)
 			if asK8sObj == nil {
-				return nil, errors.Errorf("object was not a k8s object: %v", obj)
+				return nil, fmt.Errorf("object was not a k8s object: %v", obj)
 			}
 			objs = append(objs, asK8sObj)
 		}
@@ -73,7 +77,7 @@ func parseObjects(data []byte, d runtime.Decoder) ([]k8sutil.Object, error) {
 	}
 	asK8sObj, _ := obj.(k8sutil.Object)
 	if asK8sObj == nil {
-		return nil, errors.Errorf("object was not a k8s object: %v", obj)
+		return nil, fmt.Errorf("object was not a k8s object: %v", obj)
 	}
 	// TODO: validate
 	return []k8sutil.Object{asK8sObj}, nil
@@ -100,7 +104,7 @@ func (l *lintContextImpl) renderHelmChart(dir string) (map[string]string, error)
 	valOpts := &values.Options{ValueFiles: []string{filepath.Join(dir, "values.yaml")}}
 	values, err := valOpts.MergeValues(nil)
 	if err != nil {
-		return nil, errors.Wrap(err, "loading values.yaml file")
+		return nil, fmt.Errorf("loading values.yaml file: %w", err)
 	}
 	return l.renderValues(chrt, values)
 }
@@ -114,29 +118,30 @@ func (l *lintContextImpl) renderValues(chrt *chart.Chart, values map[string]inte
 	e := engine.Engine{LintMode: true}
 	rendered, err := e.Render(chrt, valuesToRender)
 	if err != nil {
-		return nil, errors.Wrap(err, "failed to render")
+		return nil, fmt.Errorf("failed to render: %w", err)
 	}
 
 	return rendered, nil
 }
 
-func (l *lintContextImpl) loadObjectsFromHelmChart(dir string) {
+func (l *lintContextImpl) loadObjectsFromHelmChart(dir string, ignorePaths []string) error {
 	renderedFiles, err := l.renderHelmChart(dir)
 	if err != nil {
 		l.addInvalidObjects(InvalidObject{Metadata: ObjectMetadata{FilePath: dir}, LoadErr: err})
-		return
+		return nil
 	}
+
 	// Paths returned by helm include redundant directory in front, therefore we strip it out.
-	l.loadHelmRenderedTemplates(dir, normalizeDirectoryPaths(renderedFiles))
+	return l.loadHelmRenderedTemplates(dir, normalizeDirectoryPaths(renderedFiles), ignorePaths)
 }
 
-func (l *lintContextImpl) loadObjectsFromTgzHelmChart(tgzFile string) {
+func (l *lintContextImpl) loadObjectsFromTgzHelmChart(tgzFile string, ignorePaths []string) error {
 	renderedFiles, err := l.renderTgzHelmChart(tgzFile)
 	if err != nil {
 		l.addInvalidObjects(InvalidObject{Metadata: ObjectMetadata{FilePath: tgzFile}, LoadErr: err})
-		return
+		return nil
 	}
-	l.loadHelmRenderedTemplates(tgzFile, renderedFiles)
+	return l.loadHelmRenderedTemplates(tgzFile, renderedFiles, ignorePaths)
 }
 
 func (l *lintContextImpl) renderTgzHelmChart(tgzFile string) (map[string]string, error) {
@@ -189,7 +194,7 @@ func (l *lintContextImpl) loadObjectsFromYAMLFile(filePath string, info os.FileI
 	}
 	file, err := os.Open(filepath.Clean(filePath))
 	if err != nil {
-		return errors.Wrapf(err, "opening file at %s", filePath)
+		return fmt.Errorf("opening file at %s: %w", filePath, err)
 	}
 	defer func() {
 		_ = file.Close()
@@ -202,7 +207,7 @@ func (l *lintContextImpl) loadObjectsFromReader(filePath string, reader io.Reade
 	yamlReader := yaml.NewYAMLReader(bufio.NewReader(reader))
 	for {
 		if err := l.loadObjectFromYAMLReader(filePath, yamlReader); err != nil {
-			if err == io.EOF {
+			if errors.Is(err, io.EOF) {
 				return nil
 			}
 			return err
@@ -225,12 +230,12 @@ func (l *lintContextImpl) renderChart(fileName string, chart *chart.Chart) (map[
 
 	indexName := filepath.Join(fileName, "values.yaml")
 	if valuesIndex == -1 {
-		return nil, errors.Errorf("%s not found", indexName)
+		return nil, fmt.Errorf("%s not found", indexName)
 	}
 
 	values := map[string]interface{}{}
 	if err := y.Unmarshal(chart.Raw[valuesIndex].Data, &values); err != nil {
-		return nil, errors.Wrapf(err, "failed to parse values file %s", indexName)
+		return nil, fmt.Errorf("failed to parse values file %s: %w", indexName, err)
 	}
 
 	return l.renderValues(chart, values)
@@ -249,29 +254,42 @@ func (l *lintContextImpl) renderTgzHelmChartReader(fileName string, tgzReader io
 	return l.renderChart(fileName, chrt)
 }
 
-func (l *lintContextImpl) readObjectsFromTgzHelmChart(fileName string, tgzReader io.Reader) {
+func (l *lintContextImpl) readObjectsFromTgzHelmChart(fileName string, tgzReader io.Reader, ignoredPaths []string) error {
 	renderedFiles, err := l.renderTgzHelmChartReader(fileName, tgzReader)
 	if err != nil {
 		l.addInvalidObjects(InvalidObject{Metadata: ObjectMetadata{FilePath: fileName}, LoadErr: err})
-		return
+		return nil
 	}
-	l.loadHelmRenderedTemplates(fileName, renderedFiles)
+	return l.loadHelmRenderedTemplates(fileName, renderedFiles, ignoredPaths)
 }
 
-func (l *lintContextImpl) loadHelmRenderedTemplates(chartPath string, renderedFiles map[string]string) {
+func (l *lintContextImpl) loadHelmRenderedTemplates(chartPath string, renderedFiles map[string]string, ignorePaths []string) error {
+nextFile:
 	for path, contents := range renderedFiles {
 		pathToTemplate := filepath.Join(chartPath, path)
 
+		for _, path := range ignorePaths {
+			ignoreMatch, err := doublestar.PathMatch(path, pathToTemplate)
+			if err != nil {
+				return fmt.Errorf("could not match pattern %s: %w", path, err)
+			}
+			if ignoreMatch {
+				continue nextFile
+			}
+		}
+
 		// Skip NOTES.txt file that may be present among templates but is not a kubernetes resource.
 		if strings.HasSuffix(pathToTemplate, string(filepath.Separator)+chartutil.NotesName) {
 			continue
 		}
 
 		if err := l.loadObjectsFromReader(pathToTemplate, strings.NewReader(contents)); err != nil {
-			loadErr := errors.Wrapf(err, "loading object %s from rendered helm chart %s", pathToTemplate, chartPath)
+			loadErr := fmt.Errorf("loading object %s from rendered helm chart %s: %w", pathToTemplate, chartPath, err)
 			l.addInvalidObjects(InvalidObject{Metadata: ObjectMetadata{FilePath: pathToTemplate}, LoadErr: loadErr})
 		}
 	}
+
+	return nil
 }
 
 // normalizeDirectoryPaths removes the first element of the path that gets added by the Helm library.
