@@ -12,6 +12,7 @@ import (
 	_ "golang.stackrox.io/kube-linter/pkg/templates/danglingnetworkpolicy"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/danglingnetworkpolicypeer"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/danglingservice"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/danglingservicemonitor"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/deprecatedserviceaccount"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/disallowedgvk"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/dnsconfigoptions"
@@ -24,7 +25,9 @@ import (
 	_ "golang.stackrox.io/kube-linter/pkg/templates/hostpid"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/hpareplicas"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/imagepullpolicy"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/jobttlsecondsafterfinished"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/latesttag"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/livenessport"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/livenessprobe"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/memoryrequirements"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/mismatchingselector"
@@ -32,19 +35,27 @@ import (
 	_ "golang.stackrox.io/kube-linter/pkg/templates/nodeaffinity"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/nonexistentserviceaccount"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/nonisolatedpod"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/pdbmaxunavailable"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/pdbminavailable"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/pdbunhealthypodevictionpolicy"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/ports"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/priorityclassname"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/privileged"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/privilegedports"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/privilegeescalation"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/readinessport"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/readinessprobe"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/readonlyrootfs"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/readsecret"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/replicas"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/requiredannotation"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/requiredlabel"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/restartpolicy"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/runasnonroot"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/sccdenypriv"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/serviceaccount"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/servicetype"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/startupport"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/sysctl"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/targetport"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/unsafeprocmount"
