@@ -3,7 +3,6 @@ package util
 import (
 	"fmt"
 
-	"github.com/pkg/errors"
 	"golang.stackrox.io/kube-linter/internal/stringutils"
 	"golang.stackrox.io/kube-linter/pkg/check"
 	"golang.stackrox.io/kube-linter/pkg/diagnostic"
@@ -17,11 +16,11 @@ import (
 func ConstructRequiredMapMatcher(key, value, fieldType string) (check.Func, error) {
 	keyMatcher, err := matcher.ForString(key)
 	if err != nil {
-		return nil, errors.Wrap(err, "invalid key")
+		return nil, fmt.Errorf("invalid key: %w", err)
 	}
 	valueMatcher, err := matcher.ForString(value)
 	if err != nil {
-		return nil, errors.Wrap(err, "invalid value")
+		return nil, fmt.Errorf("invalid value: %w", err)
 	}
 
 	var extractFunc func(object k8sutil.Object) map[string]string
@@ -31,7 +30,7 @@ func ConstructRequiredMapMatcher(key, value, fieldType string) (check.Func, erro
 	case "annotation":
 		extractFunc = extract.Annotations
 	default:
-		return nil, errors.Errorf("unknown fieldType %q", fieldType)
+		return nil, fmt.Errorf("unknown fieldType %q", fieldType)
 	}
 
 	return func(_ lintcontext.LintContext, object lintcontext.Object) []diagnostic.Diagnostic {
