@@ -8,6 +8,6 @@ package toolimports
 // for an explanation of the approach.
 
 import (
-	_ "github.com/golangci/golangci-lint/cmd/golangci-lint"
-	_ "k8s.io/cli-runtime/pkg/resource" // This is imported because we want to be able to require it at a certain version, since otherwise Helm breaks.
+	_ "github.com/golangci/golangci-lint/v2/cmd/golangci-lint"
+	_ "github.com/goreleaser/goreleaser"
 )
